Version 0.2.1
-------------

* Fixed packaging bug (no templates or static media)

Version 0.2
-----------

* 'inner row' and 'inner column' commands
* Added ability to group CSS classes by category
* Compatibility with Django 1.3 and django-cms 2.1.3
* Lots of bug fixes and refinements


Version 0.1
-----------

Initial release


